Welcome
=======

Kubify OS, Version: 9013.0.2

Turn-Key DevOps/MLOps Stack

Rapid Development Platform


Getting Started
===============

1. `kubify --up`
2. `cd ./services/[]/[]`
3. `kubify --start`

Happy Devs